@@ -1,11 +1,12 @@
 #' Subgroup Identification: Model-based partitioning (Weibull)
 #'
-#' Uses the MOB (with weibull loss function) algorithm to identify subgroups.
-#' Usable for survival outcomes.
+#' Uses the MOB (with weibull loss function) algorithm to identify subgroups
+#' (Zeileis, Hothorn, Hornik 2008; Seibold, Zeileis, Hothorn 2016). Usable for
+#' survival outcomes.
 #'
 #' @param Y The outcome variable. Must be numeric or survival (ex; Surv(time,cens) )
 #' @param A Treatment variable. (a=1,...A)
-#' @param X Covariate matrix. Must be numeric.
+#' @param X Covariate space.
 #' @param Xtest Test set
 #' @param mu_train Patient-level estimates (See PLE_models)
 #' @param minsize Minimum number of observations in a tree node.
@@ -15,13 +16,9 @@
 #'
 #' @import survival
 #'
-#' @return MOB (Weibull) model, predictions, and identified subgroups.
+#' @return Trained MOB (Weibull) model.
 #'  \itemize{
 #'   \item mod - MOB (Weibull) model object
-#'   \item Subgrps.train - Identified subgroups (training set)
-#'   \item Subgrps.test - Identified subgroups (test set)
-#'   \item pred.train - Predictions (training set)
-#'   \item pred.test - Predictions (test set)
 #' }
 #'
 #' @export
@@ -41,7 +38,6 @@
 #' plot(res_weibull$mod)
 #' }
 #'
-#' @seealso \code{\link{PRISM}}, \code{\link{mob}}
 #'
 ## MOB: Weibull ##
 submod_weibull = function(Y, A, X, Xtest, mu_train, minsize = floor( dim(X)[1]*0.05  ),
@@ -59,19 +55,72 @@ submod_weibull = function(Y, A, X, Xtest, mu_train, minsize = floor( dim(X)[1]*0
   mod <- mob(Y ~ A | ., data = X,
              fit = wbreg, control = mob_control(parm=1:3, minsize=minsize,
                                                 maxdepth=maxdepth))
-  ##  Predict Subgroups for Train/Test ##
-  Subgrps.train = as.numeric( predict(mod, type="node") )
-  Subgrps.test = as.numeric( predict(mod, type="node", newdata = Xtest) )
-  # ## Predict Hazard Ratio across subgroups ##
-  # for (sub in unique(Subgrps.train)){
-  #   # Extract Model #
-  #   mod.s = summary(mod)[]
-  #
-  # }
-  ## Predict E(Y|X=x, A=1)-E(Y|X=x,A=0) ##
-  pred.train = NA
-  pred.test =  NA
+
+  res = list(mod=mod)
+  class(res) = "submod_weibull"
   ## Return Results ##
-  return(  list(mod=mod, Subgrps.train=Subgrps.train, Subgrps.test=Subgrps.test,
-                pred.train=pred.train, pred.test=pred.test) )
+  return(  res  )
 }
+
+#' Predict submod: Model-based partitioning (Weibull)
+#'
+#' Predict subgroups and obtain subgroup-specific point-estimates (in pprogress).
+#'
+#' @param object Trained MOB (Weibull) model.
+#' @param newdata Data-set to make predictions at (Default=NULL, predictions correspond
+#' to training data).
+#' @param ... Any additional parameters, not currently passed through.
+#'
+#' @import partykit
+#' @importFrom stats coefficients
+#'
+#' @return Identified subgroups with subgroup-specific predictions.
+#' \itemize{
+#'   \item Subgrps - Identified subgroups
+#'   \item pred - Predictions, based on weibull regression fit, estimate hazard ratio
+#'   by subgroup.
+#'}
+#' @examples
+#'
+#' \donttest{
+#' library(StratifiedMedicine)
+#' # Survival Data #
+#' require(TH.data); require(coin)
+#' data("GBSG2", package = "TH.data")
+#' surv.dat = GBSG2
+#' # Design Matrices #
+#' Y = with(surv.dat, Surv(time, cens))
+#' X = surv.dat[,!(colnames(surv.dat) %in% c("time", "cens")) ]
+#' A = rbinom( n = dim(X)[1], size=1, prob=0.5  ) ## simulate null treatment
+#'
+#' res_weibull = submod_weibull(Y, A, X, Xtest=X, family="survival")
+#' out = predict(res_weibull)
+#' plot(res_weibull$mod)
+#' }
+#'
+#'
+#' @method predict submod_weibull
+#' @export
+#'
+predict.submod_weibull = function(object, newdata=NULL, ...){
+
+  # Extract mod #
+  mod = object$mod
+  ##  Predict Subgroups ##
+  Subgrps = as.numeric( predict(mod, type="node", newdata = newdata) )
+
+  ### Predict Hazard Ratio (based on weibull model predictions) ##
+  hold.dat = data.frame(Subgrps = Subgrps, pred = NA)
+  for (s in unique(Subgrps)){
+    hold = summary(mod)[[as.character(s)]]
+    b0 = as.numeric( coefficients(hold)[1] )
+    b1 = as.numeric( coefficients(hold)[2] )
+    scale = hold$scale
+    hold.dat$pred[hold.dat$Subgrps==s] = exp( -b1 / scale )
+  }
+  pred = hold.dat$pred
+
+  ## Return Results ##
+  return(  list(Subgrps=Subgrps, pred=pred) )
+}
+
